validator-collection-br
=======================

Validadores para campos específicos do Brasil

- CPF - Cadastro de Pessoas Físicas
- CNPJ - Cadastro Nacional da Pessoa Jurídica
- CNJ - Numeração única do Conselho Nacional de Justiça - Em progresso
- Nome completo - Permite caracteres maiúsculos e minúsculos, com e sem acentuação, apóstrofo, hífen e deve ter pelo menos um espaço entre as palavras.